ChangeLog

Struct ChangeLog 

pub struct ChangeLog {
Show 14 fields pub change_time: Option<String>, pub kind: Option<String>, pub subaccount_id: Option<String>, pub old_value: Option<String>, pub object_id: Option<String>, pub id: Option<String>, pub user_profile_name: Option<String>, pub field_name: Option<String>, pub user_profile_id: Option<String>, pub action: Option<String>, pub transaction_id: Option<String>, pub account_id: Option<String>, pub new_value: Option<String>, pub object_type: Option<String>,
}
Describes a change that a user has made to a resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

change_time: Option<String>

Time when the object was modified.

kind: Option<String>

Identifies what kind of resource this is. Value: the fixed string “dfareporting#changeLog”.

subaccount_id: Option<String>

Subaccount ID of the modified object.

old_value: Option<String>

Old value of the object field.

object_id: Option<String>

ID of the object of this change log. The object could be a campaign, placement, ad, or other type.

id: Option<String>

ID of this change log.

user_profile_name: Option<String>

User profile name of the user who modified the object.

field_name: Option<String>

Field name of the object which changed.

user_profile_id: Option<String>

ID of the user who modified the object.

action: Option<String>

Action which caused the change.

transaction_id: Option<String>

Transaction ID of this change log. When a single API call results in many changes, each change will have a separate ID in the change log but will share the same transactionId.

account_id: Option<String>

Account ID of the modified object.

new_value: Option<String>

New value of the object field.

object_type: Option<String>

Object type of the change log.