pub struct ChangeLogListCall<'a, C, A>where
C: 'a,
A: 'a,{ /* private fields */ }Expand description
Retrieves a list of change logs.
A builder for the list method supported by a changeLog resource.
It is not used directly, but through a ChangeLogMethods instance.
Example
Instantiate a resource method builder
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.change_logs().list("profileId")
.add_user_profile_ids("labore")
.search_string("sed")
.page_token("ea")
.object_type("gubergren")
.add_object_ids("aliquyam")
.min_change_time("eos")
.max_results(-38)
.max_change_time("sea")
.add_ids("labore")
.action("ipsum")
.doit();Implementations
Sourceimpl<'a, C, A> ChangeLogListCall<'a, C, A>
impl<'a, C, A> ChangeLogListCall<'a, C, A>
Sourcepub fn doit(self) -> Result<(Response, ChangeLogsListResponse)>
pub fn doit(self) -> Result<(Response, ChangeLogsListResponse)>
Perform the operation you have build so far.
Sourcepub fn profile_id(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn profile_id(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
User profile ID associated with this request.
Sets the profile id path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
Sourcepub fn add_user_profile_ids(
self,
new_value: &str,
) -> ChangeLogListCall<'a, C, A>
pub fn add_user_profile_ids( self, new_value: &str, ) -> ChangeLogListCall<'a, C, A>
Select only change logs with these user profile IDs.
Append the given value to the user profile ids query property. Each appended value will retain its original ordering and be ‘/’-separated in the URL’s parameters.
Sourcepub fn search_string(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn search_string(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs whose object ID, user name, old or new values match the search string.
Sets the search string query property to the given value.
Sourcepub fn page_token(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn page_token(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Value of the nextPageToken from the previous result page.
Sets the page token query property to the given value.
Sourcepub fn object_type(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn object_type(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs with the specified object type.
Sets the object type query property to the given value.
Sourcepub fn add_object_ids(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn add_object_ids(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs with these object IDs.
Append the given value to the object ids query property. Each appended value will retain its original ordering and be ‘/’-separated in the URL’s parameters.
Sourcepub fn min_change_time(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn min_change_time(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs whose change time is before the specified minChangeTime.The time should be formatted as an RFC3339 date/time string. For example, for 10:54 PM on July 18th, 2015, in the America/New York time zone, the format is “2015-07-18T22:54:00-04:00”. In other words, the year, month, day, the letter T, the hour (24-hour clock system), minute, second, and then the time zone offset.
Sets the min change time query property to the given value.
Sourcepub fn max_results(self, new_value: i32) -> ChangeLogListCall<'a, C, A>
pub fn max_results(self, new_value: i32) -> ChangeLogListCall<'a, C, A>
Maximum number of results to return.
Sets the max results query property to the given value.
Sourcepub fn max_change_time(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn max_change_time(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs whose change time is before the specified maxChangeTime.The time should be formatted as an RFC3339 date/time string. For example, for 10:54 PM on July 18th, 2015, in the America/New York time zone, the format is “2015-07-18T22:54:00-04:00”. In other words, the year, month, day, the letter T, the hour (24-hour clock system), minute, second, and then the time zone offset.
Sets the max change time query property to the given value.
Sourcepub fn add_ids(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn add_ids(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs with these IDs.
Append the given value to the ids query property. Each appended value will retain its original ordering and be ‘/’-separated in the URL’s parameters.
Sourcepub fn action(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
pub fn action(self, new_value: &str) -> ChangeLogListCall<'a, C, A>
Select only change logs with the specified action.
Sets the action query property to the given value.
Sourcepub fn delegate(
self,
new_value: &'a mut dyn Delegate,
) -> ChangeLogListCall<'a, C, A>
pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> ChangeLogListCall<'a, C, A>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.
Sets the delegate property to the given value.
Sourcepub fn param<T>(self, name: T, value: T) -> ChangeLogListCall<'a, C, A>
pub fn param<T>(self, name: T, value: T) -> ChangeLogListCall<'a, C, A>
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known paramters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. Overrides userIp if both are provided.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- userIp (query-string) - IP address of the site where the request originates. Use this if you want to enforce per-user limits.
- fields (query-string) - Selector specifying which fields to include in a partial response.
- alt (query-string) - Data format for the response.
Sourcepub fn add_scope<T, S>(self, scope: T) -> ChangeLogListCall<'a, C, A>
pub fn add_scope<T, S>(self, scope: T) -> ChangeLogListCall<'a, C, A>
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead the default Scope variant
Scope::Dfatrafficking.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
If None is specified, then all scopes will be removed and no default scope will be used either.
In that case, you have to specify your API-key using the key parameter (see the param()
function for details).
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.