pub struct FloodlightActivityMethods<'a, C, A>where
C: 'a,
A: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on floodlightActivity resources.
It is not used directly, but through the Dfareporting hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_dfareporting2d3 as dfareporting2d3;
use std::default::Default;
use oauth2::{Authenticator, DefaultAuthenticatorDelegate, ApplicationSecret, MemoryStorage};
use dfareporting2d3::Dfareporting;
let secret: ApplicationSecret = Default::default();
let auth = Authenticator::new(&secret, DefaultAuthenticatorDelegate,
hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())),
<MemoryStorage as Default>::default(), None);
let mut hub = Dfareporting::new(hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `generatetag(...)`, `get(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.floodlight_activities();Implementations
Sourceimpl<'a, C, A> FloodlightActivityMethods<'a, C, A>
impl<'a, C, A> FloodlightActivityMethods<'a, C, A>
Sourcepub fn get(
&self,
profile_id: &str,
id: &str,
) -> FloodlightActivityGetCall<'a, C, A>
pub fn get( &self, profile_id: &str, id: &str, ) -> FloodlightActivityGetCall<'a, C, A>
Create a builder to help you perform the following task:
Gets one floodlight activity by ID.
Arguments
profileId- User profile ID associated with this request.id- Floodlight activity ID.
Sourcepub fn list(&self, profile_id: &str) -> FloodlightActivityListCall<'a, C, A>
pub fn list(&self, profile_id: &str) -> FloodlightActivityListCall<'a, C, A>
Create a builder to help you perform the following task:
Retrieves a list of floodlight activities, possibly filtered.
Arguments
profileId- User profile ID associated with this request.
Sourcepub fn insert(
&self,
request: FloodlightActivity,
profile_id: &str,
) -> FloodlightActivityInsertCall<'a, C, A>
pub fn insert( &self, request: FloodlightActivity, profile_id: &str, ) -> FloodlightActivityInsertCall<'a, C, A>
Create a builder to help you perform the following task:
Inserts a new floodlight activity.
Arguments
request- No description provided.profileId- User profile ID associated with this request.
Sourcepub fn delete(
&self,
profile_id: &str,
id: &str,
) -> FloodlightActivityDeleteCall<'a, C, A>
pub fn delete( &self, profile_id: &str, id: &str, ) -> FloodlightActivityDeleteCall<'a, C, A>
Create a builder to help you perform the following task:
Deletes an existing floodlight activity.
Arguments
profileId- User profile ID associated with this request.id- Floodlight activity ID.
Sourcepub fn patch(
&self,
request: FloodlightActivity,
profile_id: &str,
id: &str,
) -> FloodlightActivityPatchCall<'a, C, A>
pub fn patch( &self, request: FloodlightActivity, profile_id: &str, id: &str, ) -> FloodlightActivityPatchCall<'a, C, A>
Create a builder to help you perform the following task:
Updates an existing floodlight activity. This method supports patch semantics.
Arguments
request- No description provided.profileId- User profile ID associated with this request.id- Floodlight activity ID.
Sourcepub fn generatetag(
&self,
profile_id: &str,
) -> FloodlightActivityGeneratetagCall<'a, C, A>
pub fn generatetag( &self, profile_id: &str, ) -> FloodlightActivityGeneratetagCall<'a, C, A>
Create a builder to help you perform the following task:
Generates a tag for a floodlight activity.
Arguments
profileId- User profile ID associated with this request.
Sourcepub fn update(
&self,
request: FloodlightActivity,
profile_id: &str,
) -> FloodlightActivityUpdateCall<'a, C, A>
pub fn update( &self, request: FloodlightActivity, profile_id: &str, ) -> FloodlightActivityUpdateCall<'a, C, A>
Create a builder to help you perform the following task:
Updates an existing floodlight activity.
Arguments
request- No description provided.profileId- User profile ID associated with this request.