pub struct LandingPage {
pub default: Option<bool>,
pub url: Option<String>,
pub kind: Option<String>,
pub id: Option<String>,
pub name: Option<String>,
}Expand description
Contains information about where a user’s browser is taken after the user clicks an ad.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- update landing pages (request|response)
- list landing pages (none)
- patch landing pages (request|response)
- insert landing pages (request|response)
- delete landing pages (none)
- get landing pages (response)
Fields
default: Option<bool>Whether or not this landing page will be assigned to any ads or creatives that do not have a landing page assigned explicitly. Only one default landing page is allowed per campaign.
url: Option<String>URL of this landing page. This is a required field.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#landingPage”.
id: Option<String>ID of this landing page. This is a read-only, auto-generated field.
name: Option<String>Name of this landing page. This is a required field. It must be less than 256 characters long, and must be unique among landing pages of the same campaign.